@@ -1,5 +1,5 @@
 from baseoperation import BaseOperation
-from artifactcli import BasicInfo
+from artifactcli.artifact import BasicInfo
 
 
 class UploadOperation(BaseOperation):
